@@ -1721,11 +1721,9 @@ void HTMLTokenizer::write( const TokenizerString &str, bool appendData )
         else if ( startTag )
         {
             startTag = false;
-            bool endTag = false;
 
             switch(cc) {
             case '/':
-                endTag = true;
                 break;
             case '!':
             {
